@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2017 Montel Laurent <montel@kde.org>
+   Copyright (C) 2013-2018 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -35,7 +35,7 @@ class GrantleePrintStyle : public PrintStyle
 
 public:
     explicit GrantleePrintStyle(const QString &themePath, PrintingWizard *parent);
-    ~GrantleePrintStyle();
+    ~GrantleePrintStyle() override;
 
     void print(const KContacts::Addressee::List &, PrintProgress *) override;
 private:
